.. _reference:

Reference
=========

.. toctree::

    high_level_interface
    descriptive/index.rst
    distribution/index.rst
    polynomial/index.rst
    sampling
    quadrature/index.rst
    recurrence
